A dataset of Mediterranean shipwrecks.
shipwrecksA data.frame with 1784 observations (wrecks) and 13 variables:
character: wreck name.
character: region of the sea where the wreck was discovered.
character: country where the wreck was discovered.
character: region where the wreck was discovered.
integer: minimum depth of the wreck (m).
integer: maximum depth of the wreck (m).
character: depth of the wreck (m).
character: chronology (period).
character: chronology (dating).
integer: earliest date.
integer: latest date.
character: place of origin.
character: place of destination.
Parker, A. J. (1992). Ancient Shipwrecks of the Mediterranean and the Roman Provinces. British Archaeological Reports International Series 580. Oxford.
Strauss, E. J. (2007). Roman Cargoes: Underwater Evidence from the Eastern Mediterranean. Doctoral thesis, University College London. URL: https://discovery.ucl.ac.uk/id/eprint/1349806.
Other artefact data:
munsingen